==> CGATReport-0.1.tar.gz: CGATReport-0.1/setup.py <==
########################################################################
# Import setuptools
# Use existing setuptools
try:
    from setuptools import setup, find_packages
except ImportError:
    # try to get via ez_setup
    # ez_setup did not work on all machines tested as
    # it uses curl with https protocol, which is not
    # enabled in ScientificLinux
    import ez_setup
    ez_setup.use_setuptools()
    from setuptools import setup, find_packages

import glob
import sys
import os
import re
import distutils.sysconfig
import stat

major, minor1, minor2, s, tmp = sys.version_info


#####################################################################
# Code to install dependencies from a repository
#####################################################################
# Modified from http://stackoverflow.com/a/9125399
#####################################################################
def which(program):
    """
    Detect whether or not a program is installed.
    Thanks to http://stackoverflow.com/a/377028/70191
    """
    def is_exe(fpath):
        return os.path.exists(fpath) and os.access(fpath, os.X_OK)

    fpath, _ = os.path.split(program)
    if fpath:
        if is_exe(program):
            return program
    else:
        for path in os.environ['PATH'].split(os.pathsep):
            exe_file = os.path.join(path, program)
            if is_exe(exe_file):
                return exe_file

    return None

REPO_REQUIREMENT = re.compile(
    r'^-e (?P<link>(?P<vcs>git|svn|hg|bzr).+#egg=(?P<package>.+)-(?P<version>\d(?:\.\d)*))$')
HTTPS_REQUIREMENT = re.compile(
    r'^-e (?P<link>.*).+#(?P<package>.+)-(?P<version>\d(?:\.\d)*)$')
install_requires = []
dependency_links = []

for requirement in (l.strip() for l in open('requires.txt')
                    if not l.startswith("#")):
    match = REPO_REQUIREMENT.match(requirement)
    if match:
        assert which(match.group('vcs')) is not None, \
            "VCS '%(vcs)s' must be installed in order " \
            "to install %(link)s" % match.groupdict()
        install_requires.append("%(package)s==%(version)s" % match.groupdict())
        dependency_links.append(match.group('link'))
        continue

    if requirement.startswith("https"):
        install_requires.append(requirement)
        continue

    match = HTTPS_REQUIREMENT.match(requirement)
    if match:
        install_requires.append("%(package)s>=%(version)s" % match.groupdict())
        dependency_links.append(match.group('link'))
        continue

    install_requires.append(requirement)

if major == 2:
    install_requires.extend(['web.py>=0.37',
                             'xlwt>=0.7.4',
                             'matplotlib-venn>=0.5'])
elif major == 3:
    pass

if major == 2 and minor1 < 5 or major < 2:
    raise SystemExit("""CGATReport requires Python 2.5 or later.""")

classifiers = """
Development Status :: 4 - Beta
Intended Audience :: Science/Research
Intended Audience :: Developers
License :: OSI Approved
Programming Language :: Python
Topic :: Software Development
Topic :: Scientific/Engineering
Operating System :: Microsoft :: Windows
Operating System :: POSIX
Operating System :: Unix
Operating System :: MacOS
"""

# external dependencies
# R
# sqlite
# R - ggplot2
# R - RSqlite
# R - gplots (for r-heatmap)
# graphvis - for dependency graphs in documentation

setup(name='CGATReport',
      version='0.1',
      description='CGATReport : a report generator in python based on sphinx',
      author='Andreas Heger',
      author_email='andreas.heger@gmail.com',
      packages=find_packages(),
      package_dir={'CGATReport': 'CGATReport',
                   'CGATReportPlugins': 'CGATReportPlugins'},
      url="https://github.com/AndreasHeger/sphinx-report/",
      scripts=['scripts/cgatreport-%s' % x
               for x in ("build", "clean", "test", "quickstart", "gallery")],
      package_data={'CGATReport': ['./templates/*', './images/*']},
      license="BSD",
      platforms=["any"],
      keywords="report generator sphinx matplotlib sql",
      long_description='CGATReport : a report generator in python based '
      'on sphinx',
      classifiers=filter(None, classifiers.split("\n")),
      install_requires=install_requires,
      zip_safe=False,
      include_package_data=True,
      test_suite="tests",
      # python 3 conversion, requires distribute
      # use_2to3 = True,
      entry_points={
          'console_scripts': [
              'cgatreport-build = CGATReport.build:main',
              'cgatreport-clean = CGATReport.clean:main',
              'cgatreport-test = CGATReport.test:main',
              'cgatreport-quickstart = CGATReport.quickstart:main',
              'cgatreport-get = CGATReport.get:main',
              'cgatreport-profile = CGATReport.profile:main',
              'cgatreport-serve = CGATReport.serve:main',
          ],
          'distutils.commands': [
              'build_sphinx = cgatreport.setup_command:BuildDoc',
          ],
          'CGATReport.plugins': [
              'matplotlib=CGATReportPlugins.MatplotlibPlugin:MatplotlibPlugin',
              'rplot=CGATReportPlugins.RPlotPlugin:RPlotPlugin',
              'html=CGATReportPlugins.HTMLPlugin:HTMLPlugin',
              'rst=CGATReportPlugins.RSTPlugin:RSTPlugin',
              'xls=CGATReportPlugins.XLSPlugin:XLSPlugin',
              'bokeh=CGATReportPlugins.BokehPlugin:BokehPlugin',
              'transform-stats=CGATReportPlugins.Transformer:TransformerStats',
              'transform-correlation=CGATReportPlugins.Transformer:TransformerCorrelationPearson',
              'transform-pearson=CGATReportPlugins.Transformer:TransformerCorrelationPearson',
              'transform-contingency=CGATReportPlugins.Transformer:TransformerContingency',
              'transform-spearman=CGATReportPlugins.Transformer:TransformerCorrelationSpearman', 
              'transform-test-mwu=CGATReportPlugins.Transformer:TransformerMannWhitneyU', 
              'transform-aggregate=CGATReportPlugins.Transformer:TransformerAggregate',
              'transform-histogram=CGATReportPlugins.Transformer:TransformerHistogram',
              'transform-tolabels=CGATReportPlugins.Transformer:TransformerToLabels',
              'transform-filter=CGATReportPlugins.Transformer:TransformerFilter',
              # 'transform-indicator=CGATReportPlugins.Transformer:TransformerIndicator',
              'transform-select=CGATReportPlugins.Transformer:TransformerSelect',
              'transform-swop=CGATReportPlugins.Transformer:TransformerSwop',
              'transform-group=CGATReportPlugins.Transformer:TransformerGroup',
              'transform-combinations=CGATReportPlugins.Transformer:TransformerCombinations',
              'transform-combine=CGATReportPlugins.Transformer:TransformerCombinations',
              'transform-tolist=CGATReportPlugins.Transformer:TransformerToList',
              'transform-toframe=CGATReportPlugins.Transformer:TransformerToDataFrame',
              'transform-melt=CGATReportPlugins.Transformer:TransformerMelt',
              'transform-count=CGATReportPlugins.Transformer:TransformerCount',
              'transform-hypergeometric=CGATReportPlugins.TransformersGeneLists:TransformerHypergeometric',
              # 'transform-label-paths=CGATReportPlugins.TransformersGeneLists:TransformerPathToLabel',
              'transform-venn=CGATReportPlugins.TransformersGeneLists:TransformerVenn',
              'transform-p-adjust=CGATReportPlugins.TransformersGeneLists:TransformerMultiTest',
              'transform-odds-ratio=CGATReportPlugins.TransformersGeneLists:TransformerOddsRatio',
              'render-user=CGATReportPlugins.Renderer:User',
              'render-debug=CGATReportPlugins.Renderer:Debug',
              'render-dataframe=CGATReportPlugins.Renderer:DataFrame',
              'render-table=CGATReportPlugins.Renderer:Table',
              'render-rst-table=CGATReportPlugins.Renderer:RstTable',
              'render-xls-table=CGATReportPlugins.Renderer:XlsTable',
              'render-html-table=CGATReportPlugins.Renderer:HTMLTable',
              'render-glossary-table=CGATReportPlugins.Renderer:GlossaryTable',
              'render-matrix=CGATReportPlugins.Renderer:TableMatrix',
              'render-matrixNP=CGATReportPlugins.Renderer:NumpyMatrix',
              'render-status=CGATReportPlugins.Renderer:Status',
              'render-line-plot=CGATReportPlugins.Plotter:LinePlot',
              'render-density-plot=CGATReportPlugins.Plotter:DensityPlot',
              'render-histogram-plot=CGATReportPlugins.Plotter:HistogramPlot',
              'render-histogram-gradient-plot=CGATReportPlugins.Plotter:HistogramGradientPlot',
              'render-pie-plot=CGATReportPlugins.Plotter:PiePlot',
              'render-scatter-plot=CGATReportPlugins.Plotter:ScatterPlot',
              'render-scatter-rainbow-plot=CGATReportPlugins.Plotter:ScatterPlotWithColor',
              'render-matrix-plot=CGATReportPlugins.Plotter:TableMatrixPlot',
              'render-matrixNP-plot=CGATReportPlugins.Plotter:NumpyMatrixPlot',
              'render-hinton-plot=CGATReportPlugins.Plotter:HintonPlot',
              'render-gallery-plot=CGATReportPlugins.Plotter:GalleryPlot',
              'render-bar-plot=CGATReportPlugins.Plotter:BarPlot',
              'render-stacked-bar-plot=CGATReportPlugins.Plotter:StackedBarPlot',
              'render-interleaved-bar-plot=CGATReportPlugins.Plotter:InterleavedBarPlot',
              'render-box-plot=CGATReportPlugins.Plotter:BoxPlot',
              'render-violin-plot=CGATReportPlugins.Plotter:ViolinPlot',
              'render-venn-plot=CGATReportPlugins.Plotter:VennPlot',
              'render-ggplot=CGATReportPlugins.GGPlotter:GGPlot',
              'render-r-line-plot=CGATReportPlugins.RPlotter:LinePlot',
              'render-r-box-plot=CGATReportPlugins.RPlotter:BoxPlot',
              'render-r-smooth-scatter-plot=CGATReportPlugins.RPlotter:SmoothScatterPlot',
              'render-r-heatmap-plot=CGATReportPlugins.RPlotter:HeatmapPlot',
              'render-r-ggplot=CGATReportPlugins.RPlotter:GGPlot',
              'render-b-line-plot=CGATReportPlugins.BokehPlotter:LinePlot',
          ]
      },)

# fix file permission for executables
# set to "group writeable"
# also updates the "sphinx" permissions
if sys.argv[0] == "install":
    print ("updating file permissions for scripts")
    for x in glob.glob(os.path.join(
            distutils.sysconfig.project_base,
            "cgat-*")):
        try:
            os.chmod(x, os.stat(x).st_mode | stat.S_IWGRP)
        except OSError:
            pass

==> CGATReport-0.2.tar.gz: CGATReport-0.2/setup.py <==
########################################################################
# Import setuptools
# Use existing setuptools
try:
    from setuptools import setup, find_packages
except ImportError:
    # try to get via ez_setup
    # ez_setup did not work on all machines tested as
    # it uses curl with https protocol, which is not
    # enabled in ScientificLinux
    import ez_setup
    ez_setup.use_setuptools()
    from setuptools import setup, find_packages

import glob
import sys
import os
import re
import distutils.sysconfig
import stat

major, minor1, minor2, s, tmp = sys.version_info


#####################################################################
# Code to install dependencies from a repository
#####################################################################
# Modified from http://stackoverflow.com/a/9125399
#####################################################################
def which(program):
    """
    Detect whether or not a program is installed.
    Thanks to http://stackoverflow.com/a/377028/70191
    """
    def is_exe(fpath):
        return os.path.exists(fpath) and os.access(fpath, os.X_OK)

    fpath, _ = os.path.split(program)
    if fpath:
        if is_exe(program):
            return program
    else:
        for path in os.environ['PATH'].split(os.pathsep):
            exe_file = os.path.join(path, program)
            if is_exe(exe_file):
                return exe_file

    return None

REPO_REQUIREMENT = re.compile(
    r'^-e (?P<link>(?P<vcs>git|svn|hg|bzr).+#egg=(?P<package>.+)-(?P<version>\d(?:\.\d)*))$')
HTTPS_REQUIREMENT = re.compile(
    r'^-e (?P<link>.*).+#(?P<package>.+)-(?P<version>\d(?:\.\d)*)$')
install_requires = []
dependency_links = []

for requirement in (l.strip() for l in open('requires.txt')
                    if not l.startswith("#")):
    match = REPO_REQUIREMENT.match(requirement)
    if match:
        assert which(match.group('vcs')) is not None, \
            "VCS '%(vcs)s' must be installed in order " \
            "to install %(link)s" % match.groupdict()
        install_requires.append("%(package)s==%(version)s" % match.groupdict())
        dependency_links.append(match.group('link'))
        continue

    if requirement.startswith("https"):
        install_requires.append(requirement)
        continue

    match = HTTPS_REQUIREMENT.match(requirement)
    if match:
        install_requires.append("%(package)s>=%(version)s" % match.groupdict())
        dependency_links.append(match.group('link'))
        continue

    install_requires.append(requirement)

if major == 2:
    install_requires.extend(['web.py>=0.37',
                             'xlwt>=0.7.4',
                             'matplotlib-venn>=0.5'])
elif major == 3:
    pass

if major == 2 and minor1 < 5 or major < 2:
    raise SystemExit("""CGATReport requires Python 2.5 or later.""")

classifiers = """
Development Status :: 4 - Beta
Intended Audience :: Science/Research
Intended Audience :: Developers
License :: OSI Approved
Programming Language :: Python
Topic :: Software Development
Topic :: Scientific/Engineering
Operating System :: Microsoft :: Windows
Operating System :: POSIX
Operating System :: Unix
Operating System :: MacOS
"""

# external dependencies
# R
# sqlite
# R - ggplot2
# R - RSqlite
# R - gplots (for r-heatmap)
# graphvis - for dependency graphs in documentation

setup(name='CGATReport',
      version='0.2',
      description='CGATReport : a report generator in python based on sphinx',
      author='Andreas Heger',
      author_email='andreas.heger@gmail.com',
      packages=find_packages(),
      package_dir={'CGATReport': 'CGATReport',
                   'CGATReportPlugins': 'CGATReportPlugins'},
      url="https://github.com/AndreasHeger/sphinx-report/",
      scripts=['scripts/cgatreport-%s' % x
               for x in ("build", "clean", "test", "quickstart", "gallery")],
      package_data={'CGATReport': ['./templates/*', './images/*']},
      license="BSD",
      platforms=["any"],
      keywords="report generator sphinx matplotlib sql",
      long_description='CGATReport : a report generator in python based '
      'on sphinx',
      classifiers=filter(None, classifiers.split("\n")),
      install_requires=install_requires,
      zip_safe=False,
      include_package_data=True,
      test_suite="tests",
      # python 3 conversion, requires distribute
      # use_2to3 = True,
      entry_points={
          'console_scripts': [
              'cgatreport-build = CGATReport.build:main',
              'cgatreport-clean = CGATReport.clean:main',
              'cgatreport-test = CGATReport.test:main',
              'cgatreport-quickstart = CGATReport.quickstart:main',
              'cgatreport-get = CGATReport.get:main',
              'cgatreport-profile = CGATReport.profile:main',
              'cgatreport-serve = CGATReport.serve:main',
          ],
          'distutils.commands': [
              'build_sphinx = cgatreport.setup_command:BuildDoc',
          ],
          'CGATReport.plugins': [
              'matplotlib=CGATReportPlugins.MatplotlibPlugin:MatplotlibPlugin',
              'rplot=CGATReportPlugins.RPlotPlugin:RPlotPlugin',
              'html=CGATReportPlugins.HTMLPlugin:HTMLPlugin',
              'rst=CGATReportPlugins.RSTPlugin:RSTPlugin',
              'xls=CGATReportPlugins.XLSPlugin:XLSPlugin',
              'bokeh=CGATReportPlugins.BokehPlugin:BokehPlugin',
              'transform-stats=CGATReportPlugins.Transformer:TransformerStats',
              'transform-correlation=CGATReportPlugins.Transformer:TransformerCorrelationPearson',
              'transform-pearson=CGATReportPlugins.Transformer:TransformerCorrelationPearson',
              'transform-contingency=CGATReportPlugins.Transformer:TransformerContingency',
              'transform-spearman=CGATReportPlugins.Transformer:TransformerCorrelationSpearman', 
              'transform-test-mwu=CGATReportPlugins.Transformer:TransformerMannWhitneyU', 
              'transform-aggregate=CGATReportPlugins.Transformer:TransformerAggregate',
              'transform-histogram=CGATReportPlugins.Transformer:TransformerHistogram',
              # 'transform-tolabels=CGATReportPlugins.Transformer:TransformerToLabels',
              'transform-filter=CGATReportPlugins.Transformer:TransformerFilter',
              # 'transform-indicator=CGATReportPlugins.Transformer:TransformerIndicator',
              # 'transform-select=CGATReportPlugins.Transformer:TransformerSelect',
              # 'transform-swop=CGATReportPlugins.Transformer:TransformerSwop',
              # 'transform-group=CGATReportPlugins.Transformer:TransformerGroup',
              # 'transform-combinations=CGATReportPlugins.Transformer:TransformerCombinations',
              # 'transform-combine=CGATReportPlugins.Transformer:TransformerCombinations',
              # 'transform-tolist=CGATReportPlugins.Transformer:TransformerToList',
              # 'transform-toframe=CGATReportPlugins.Transformer:TransformerToDataFrame',
              'transform-melt=CGATReportPlugins.Transformer:TransformerMelt',
              # 'transform-count=CGATReportPlugins.Transformer:TransformerCount',
              'transform-hypergeometric=CGATReportPlugins.TransformersGeneLists:TransformerHypergeometric',
              # 'transform-label-paths=CGATReportPlugins.TransformersGeneLists:TransformerPathToLabel',
              'transform-venn=CGATReportPlugins.TransformersGeneLists:TransformerVenn',
              'transform-p-adjust=CGATReportPlugins.TransformersGeneLists:TransformerMultiTest',
              'transform-odds-ratio=CGATReportPlugins.TransformersGeneLists:TransformerOddsRatio',
              'render-user=CGATReportPlugins.Renderer:User',
              'render-debug=CGATReportPlugins.Renderer:Debug',
              'render-dataframe=CGATReportPlugins.Renderer:DataFrame',
              'render-table=CGATReportPlugins.Renderer:Table',
              'render-rst-table=CGATReportPlugins.Renderer:RstTable',
              'render-xls-table=CGATReportPlugins.Renderer:XlsTable',
              'render-html-table=CGATReportPlugins.Renderer:HTMLTable',
              'render-glossary-table=CGATReportPlugins.Renderer:GlossaryTable',
              'render-matrix=CGATReportPlugins.Renderer:TableMatrix',
              'render-matrixNP=CGATReportPlugins.Renderer:NumpyMatrix',
              'render-status=CGATReportPlugins.Renderer:Status',
              'render-line-plot=CGATReportPlugins.Plotter:LinePlot',
              'render-density-plot=CGATReportPlugins.Plotter:DensityPlot',
              'render-histogram-plot=CGATReportPlugins.Plotter:HistogramPlot',
              # 'render-histogram-gradient-plot=CGATReportPlugins.Plotter:HistogramGradientPlot',
              'render-pie-plot=CGATReportPlugins.Plotter:PiePlot',
              'render-scatter-plot=CGATReportPlugins.Plotter:ScatterPlot',
              'render-scatter-rainbow-plot=CGATReportPlugins.Plotter:ScatterPlotWithColor',
              'render-matrix-plot=CGATReportPlugins.Plotter:TableMatrixPlot',
              'render-matrixNP-plot=CGATReportPlugins.Plotter:NumpyMatrixPlot',
              'render-hinton-plot=CGATReportPlugins.Plotter:HintonPlot',
              'render-gallery-plot=CGATReportPlugins.Plotter:GalleryPlot',
              'render-bar-plot=CGATReportPlugins.Plotter:BarPlot',
              'render-stacked-bar-plot=CGATReportPlugins.Plotter:StackedBarPlot',
              'render-interleaved-bar-plot=CGATReportPlugins.Plotter:InterleavedBarPlot',
              'render-box-plot=CGATReportPlugins.Plotter:BoxPlot',
              'render-violin-plot=CGATReportPlugins.Plotter:ViolinPlot',
              'render-venn-plot=CGATReportPlugins.Plotter:VennPlot',
              'render-ggplot=CGATReportPlugins.GGPlotter:GGPlot',
              'render-r-line-plot=CGATReportPlugins.RPlotter:LinePlot',
              'render-r-box-plot=CGATReportPlugins.RPlotter:BoxPlot',
              'render-r-smooth-scatter-plot=CGATReportPlugins.RPlotter:SmoothScatterPlot',
              'render-r-heatmap-plot=CGATReportPlugins.RPlotter:HeatmapPlot',
              'render-r-ggplot=CGATReportPlugins.RPlotter:GGPlot',
              'render-b-line-plot=CGATReportPlugins.BokehPlotter:LinePlot',
          ]
      },)

# fix file permission for executables
# set to "group writeable"
# also updates the "sphinx" permissions
if sys.argv[0] == "install":
    print ("updating file permissions for scripts")
    for x in glob.glob(os.path.join(
            distutils.sysconfig.project_base,
            "cgat-*")):
        try:
            os.chmod(x, os.stat(x).st_mode | stat.S_IWGRP)
        except OSError:
            pass
